@@ -12,7 +12,7 @@ use Plack::Util;
 use Kelp::Request;
 use Kelp::Response;
 
-our $VERSION = 0.4560;
+our $VERSION = 0.4570;
 
 # Basic attributes
 attr -host => hostname;
@@ -1254,8 +1254,6 @@ arguments.
 
 =item * Mailing list: https://groups.google.com/forum/?fromgroups#!forum/perl-kelp
 
-=item * IRC: #kelp at irc.perl.org
-
 =back
 
 =head1 AUTHOR
@@ -1264,8 +1262,12 @@ Stefan Geneshky - minimal <at> cpan.org
 
 =head1 CONTRIBUTORS
 
+Julio Fraire
+
 Maurice Aubrey
+
 David Steinbrunner
+
 Gurunandan Bhat
 
 =head1 LICENSE
